@@ -40,28 +40,28 @@ class TableRowCount extends Constraint
         $this->value     = $value;
     }
 
+    /**
+     * Returns a string representation of the constraint.
+     *
+     * @return string
+     */
+    public function toString(): string
+    {
+        return \sprintf('is equal to expected row count %d', $this->value);
+    }
+
     /**
      * Evaluates the constraint for parameter $other. Returns TRUE if the
      * constraint is met, FALSE otherwise.
      *
      * This method can be overridden to implement the evaluation algorithm.
      *
-     * @param mixed $other Value or object to evaluate.
+     * @param mixed $other value or object to evaluate
      *
      * @return bool
      */
-    protected function matches($other)
+    protected function matches($other): bool
     {
         return $other == $this->value;
     }
-
-    /**
-     * Returns a string representation of the constraint.
-     *
-     * @return string
-     */
-    public function toString()
-    {
-        return \sprintf('is equal to expected row count %d', $this->value);
-    }
 }
